<?php
/**
 * @package Product Categories Bottom Description for WooCommerce
 * @version 1.0.2
 */
/*
Plugin Name: Product Categories Bottom Description for WooCommerce
Plugin URI: https://wordpress.org/plugins/product-categories-bottom-description-woo-comerce
Description: Add a new content field to the bottom of your WooCommerce product categories, right after the products list. Improve your SEO and UX.
Author: Diego de Guindos
Author URI: https://diegoguindos.com
Version: 1.0.2
*/

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if ( is_plugin_active( 'woocommerce/woocommerce.php') ) :

	// Register details product_cat meta.
	function dgv_product_cat_register_meta() {
		register_meta( 'term', 'details', 'dgv_sanitize_details' );
	}

	// Sanitize the details custom meta field.
	function dgv_sanitize_details( $details ) {
		return wp_kses_post( $details );
	}

	// Add a details metabox to the Add New Product Category page.
	add_action( 'product_cat_add_form_fields', 'dgv_product_cat_add_details_meta' );
	function dgv_product_cat_add_details_meta() {
		wp_nonce_field( basename( __FILE__ ), 'dgv_product_cat_details_nonce' );
		?>
		<div class="form-field">
			<label for="dgv-product-cat-details"><?php esc_html_e( 'Bottom description', 'dgv' ); ?></label>
			<textarea name="dgv-product-cat-details" id="dgv-product-cat-details" rows="5" cols="40"></textarea>
			<p class="description"><?php esc_html_e( 'The content in this field will be shown after the products within the product category.', 'dgv' ); ?></p>
		</div>
		<?php
	}

	// Add a details metabox to the Edit Product Category page.
	add_action( 'product_cat_edit_form_fields', 'dgv_product_cat_edit_details_meta' );
	function dgv_product_cat_edit_details_meta( $term ) {
		$product_cat_details = get_term_meta( $term->term_id, 'details', true );
		if ( ! $product_cat_details ) {
			$product_cat_details = '';
		}
		$settings = array( 'textarea_name' => 'dgv-product-cat-details' );
		?>
		<tr class="form-field">
			<th scope="row" valign="top"><label for="dgv-product-cat-details"><?php esc_html_e( 'Bottom description', 'dgv' ); ?></label></th>
			<td>
				<?php wp_nonce_field( basename( __FILE__ ), 'dgv_product_cat_details_nonce' ); ?>
				<?php wp_editor( dgv_sanitize_details( $product_cat_details ), 'product_cat_details', $settings ); ?>
				<p class="description"><?php esc_html_e( 'The content in this field will be shown after the products within the product category.','dgv' ); ?></p>
			</td>
		</tr>
		<?php
	}

	// Display details meta on Product Category archives.
	add_action( 'woocommerce_after_main_content', 'dgv_product_cat_display_details_meta' );
	function dgv_product_cat_display_details_meta() {
		if ( ! is_tax( 'product_cat' ) ) {
			return;
		}
		$t_id = get_queried_object()->term_id;
		$details = get_term_meta( $t_id, 'details', true );
		if ( '' !== $details ) {
			?>
			<div class="product-cat-details">
				<?php echo apply_filters( 'the_content', wp_kses_post( $details ) ); ?>
			</div>
			<?php
		}
	}

	// Save Product Category details meta.
	add_action( 'create_product_cat', 'dgv_product_cat_details_meta_save' );
	add_action( 'edit_product_cat', 'dgv_product_cat_details_meta_save' );
	function dgv_product_cat_details_meta_save( $term_id ) {
		if ( ! isset( $_POST['dgv_product_cat_details_nonce'] ) || ! wp_verify_nonce( sanitize_text_field($_POST['dgv_product_cat_details_nonce']), basename( __FILE__ ) ) ) {
			return;
		}
		$old_details = get_term_meta( $term_id, 'details', true );
		$new_details = isset( $_POST['dgv-product-cat-details'] ) ? sanitize_text_field($_POST['dgv-product-cat-details']) : '';
		if ( $old_details && '' === $new_details ) {
			delete_term_meta( $term_id, 'details' );
		} else if ( $old_details !== $new_details ) {
			update_term_meta(
				$term_id,
				'details',
				dgv_sanitize_details( $new_details )
			);
		}
	}

endif;